@@ -9,6 +9,7 @@
 #' @param return_result It set to `TRUE`, it return the model estimates data frame.
 #' @param assumption_plot Generate an panel of plots that check major assumptions. It is usually recommended to inspect model assumption violation visually. In the background, it calls `performance::check_model()`.
 #' @param quite suppress printing output
+#' @param standardize The method used for standardizing the parameters. Can be NULL (default; no standardization), "refit" (for re-fitting the model on standardized data) or one of "basic", "posthoc", "smart", "pseudo". See 'Details' in parameters::standardize_parameters()
 #'
 #' @references
 #' Nakagawa, S., & Schielzeth, H. (2013). A general and simple method for obtaining R2 from generalized linear mixed-effects models. Methods in Ecology and Evolution, 4(2), 133–142. https://doi.org/10.1111/j.2041-210x.2012.00261.x
@@ -39,12 +40,13 @@ model_summary <- function(model,
                           digits = 3,
                           assumption_plot = FALSE,
                           quite = FALSE,
-                          streamline = FALSE,
-                          return_result = FALSE) {
+                          streamline = TRUE,
+                          return_result = FALSE,
+                          standardize = 'basic') {
 
   ################################################ Linear Mixed Effect Model ################################################
   ## lme package
-  if (class(model)[1] == "lme") {
+  if (inherits(model,'lme')) {
     model_type <- "Linear Mixed Effect Model (fitted using nlme)"
     predict_var <- as.character(attributes(model$terms)$variables)
     DV <- predict_var[2]
@@ -68,10 +70,10 @@ model_summary <- function(model,
       dplyr::rename(ci.lower = .data$CI_low) %>%
       dplyr::rename(ci.upper = .data$CI_high) %>%
       dplyr::select(-"CI") %>%
-      dplyr::select("Parameter", "Effects", "Coefficient", "t", "df", "SE", "p", "ci.lower", "ci.upper", "p", tidyselect::everything())
-
+      dplyr::select(-'p',tidyselect::everything(),"p")
+    
     ## lmer package
-  } else if (class(model)[1] == "lmerModLmerTest" | class(model)[1] == "lmerMod") {
+  } else if (inherits(model,'lmerMod')) {
     model_type <- "Linear Mixed Effect Model (fitted using lme4 or lmerTest)"
     formula_attribute <- stats::terms(insight::find_formula(model)$conditional)
     DV <- as.character(attributes(formula_attribute)$variables)[2]
@@ -87,19 +89,18 @@ model_summary <- function(model,
     heteroscedasticity_check <- TRUE
     collinearity_check <- TRUE
     singular_check <- TRUE
-#     lme_param <- parameters::model_parameters(model)
-#     model_summary_df <- lme_param %>%
-#       as.data.frame() %>%
-#       dplyr::rename(df = .data$df_error) %>%
-#       dplyr::rename(ci.lower = .data$CI_low) %>%
-#       dplyr::rename(ci.upper = .data$CI_high) %>%
-#       dplyr::select(-"CI") %>%
-#       dplyr::select("Parameter", "Effects", "Coefficient", "t", "df", "SE", "p", "ci.lower", "ci.upper", "p", tidyselect::everything())
-    model_summary_df = data.frame(Warning = 'Warning: Waiting for the parameters pacakge to update')
-    print('psycModel is based on the package parameters. The parameters pacakge v0.14.0 has some problem. We are waiting for them to fix. This package will update again once parameters is updated. Should not be a long time')
-    ################################################ Generalized Linear Mixed Effect Model ################################################
+    lme_param <- parameters::model_parameters(model,standardize = standardize)
+    model_summary_df <- lme_param %>%
+      as.data.frame() %>%
+      dplyr::rename(df = .data$df_error) %>%
+      dplyr::rename(ci.lower = .data$CI_low) %>%
+      dplyr::rename(ci.upper = .data$CI_high) %>%
+      dplyr::select(-"CI") %>%
+      dplyr::select(-'p',tidyselect::everything(),"p")
+
+################################################ Generalized Linear Mixed Effect Model ################################################
     # glmer model
-  } else if (class(model)[1] == "glmerMod") {
+  } else if (inherits(model,'glmerMod')) {
     model_type <- "Generalized Linear Mixed Effect Model"
     formula_attribute <- stats::terms(model@call$formula)
     DV <- as.character(attributes(formula_attribute)$variables)[2]
@@ -124,10 +125,10 @@ model_summary <- function(model,
       dplyr::rename(ci.lower = .data$CI_low) %>%
       dplyr::rename(ci.upper = .data$CI_high) %>%
       dplyr::select(-"CI") %>%
-      dplyr::select("Parameter", "Effects", "Coefficient", "z", "df", "SE", "p", "ci.lower", "ci.upper", "p", tidyselect::everything())
-
+      dplyr::select(-'p',tidyselect::everything(),"p")
+    
     ################################################ Linear Regression  ################################################
-  } else if (class(model)[1] == "lm") { # linear regression
+  } else if (inherits(model,'lm')) { # linear regression
     # Parameters for output table use
     model_type <- "Linear regression"
     predict_var <- as.character(attributes(model$terms)$predvars)
@@ -152,8 +153,9 @@ model_summary <- function(model,
       dplyr::rename(ci.lower = .data$CI_low) %>%
       dplyr::rename(ci.upper = .data$CI_high) %>%
       dplyr::select(-"CI") %>%
-      dplyr::select("Parameter", "Coefficient", "t", "df", "SE", "p", "ci.lower", "ci.upper", "p", tidyselect::everything())
-  } else if (class(model)[1] == "glm") { # glm
+      dplyr::select(-'p',tidyselect::everything(),"p")
+    
+    } else if (inherits(model,"glm")) { # glm
     model_type <- "Generazlied Linear regression"
     predict_var <- as.character(attributes(model$terms)$predvars)
     DV <- predict_var[2]
@@ -177,8 +179,8 @@ model_summary <- function(model,
       dplyr::rename(ci.lower = .data$CI_low) %>%
       dplyr::rename(ci.upper = .data$CI_high) %>%
       dplyr::select(-"CI") %>%
-      dplyr::select("Parameter", "Coefficient", "z", "SE", "df", tidyselect::everything())
-  } else {
+      dplyr::select(-'p',tidyselect::everything(),"p")
+    } else {
     model_type <- "Unable to Determined for Unknown Model"
     DV <- "Unable to Determined for Unknown Model"
     IV <- "Unable to Determined for Unknown Model"
@@ -202,16 +204,15 @@ model_summary <- function(model,
 
     warning("This model is not formally supported. Please proceed with cautious. The model is passed to parameters::parameters() to extract relevant parameters")
   }
-
-  performance_warning <- utils::capture.output(model_performance_df <- performance::model_performance(model))
-  if (length(performance_warning) > 0) {
-    warning(performance_warning)
-  }
-  colnames(model_performance_df) <- stringr::str_replace_all(pattern = "R2", replacement = "R^2", string = colnames(model_performance_df))
-  colnames(model_performance_df) <- stringr::str_replace_all(pattern = "Sigma", replacement = "$sigma$", string = colnames(model_performance_df))
+  
+    performance_warning <- utils::capture.output(model_performance_df <- performance::model_performance(model))
+    if (length(performance_warning) > 0) {
+      warning(performance_warning)
+    }
+    colnames(model_performance_df) <- stringr::str_replace_all(pattern = "R2", replacement = "R^2", string = colnames(model_performance_df))
+    colnames(model_performance_df) <- stringr::str_replace_all(pattern = "Sigma", replacement = "$sigma$", string = colnames(model_performance_df)) 
   ################################################  Output Table  ################################################
   if (quite == FALSE) { # check whether quite the entire output table
-    if (streamline == FALSE) {
       cat("\n \n")
       super_print("underline|Model Summary")
       super_print("Model Type = {model_type}")
@@ -221,7 +222,6 @@ model_summary <- function(model,
         super_print("Family = {family}")
       }
       super_print("\n")
-    }
 
     # super_print model estimates table
     super_print("underline|Model Estimates")
@@ -229,7 +229,7 @@ model_summary <- function(model,
     super_print("\n")
     # super_print model performance table
     super_print("underline|Goodness of Fit")
-    print_table(model_performance_df)
+    print_table(model_performance_df) 
     if (streamline == FALSE) {
       # Check assumption
       super_print("\n")
